@@ -109,7 +109,9 @@ class MicroDisc:
             self.sign = 1
         else:
             print('Error. Either CO or CR should be zero.') 
-        self.iLim = self.sign*4*n*F*self.D*self.C*self.a
+        self.A = np.pi*a**2
+        self.km = self.sign*4*self.D/(np.pi*self.a)
+        self.iLim = n*F*A*m0*self.C
 
     def LSV(self, E):
         kf = self.k0*np.exp(self.alphaf*self.n*self.FRT*(E-self.E0))
@@ -154,7 +156,8 @@ class MicroBand:
 
     def __init__(self, t=1, n=1, D=1e-5, cb=1e-6, w=5e-4, l=500e-4):
         self.A = w*l
-        self.iLim = 2*np.pi*n*F*self.A*D*cb/(w*np.log(64*D*t/w**2))
+        self.m0 = 2*np.pi*D/(w*log(64*D*t/w**2))
+        self.iLim = n*F*A*m0*cb
 
 
 if __name__ == '__main__':
